@@ -84,15 +84,9 @@ def __read_test_cases():
 
     test_cases = [
         ('Metadata version 1.0', params()),
-        ('Metadata version 1.1: Provides', params(
-            provides=['package'],
-        )),
         ('Metadata Version 1.0: Short long description', params(
             long_description='Short long description',
         )),
-        ('Metadata version 1.1: Obsoletes', params(
-            obsoletes=['foo'],
-        )),
         ('Metadata version 1.1: Classifiers', params(
             classifiers=[
                 'Programming Language :: Python :: 3',
@@ -116,6 +110,10 @@ def __read_test_cases():
         ('Metadata Version 2.1: Long Description Content Type', params(
             long_description_content_type='text/x-rst; charset=UTF-8',
         )),
+        ('License', params(license='MIT', )),
+        ('License multiline', params(
+            license='This is a long license \nover multiple lines',
+        )),
         pytest.param(
             'Metadata Version 2.1: Provides Extra',
             params(provides_extras=['foo', 'bar']),
